@@ -23,7 +23,7 @@ package Rex::Config;
 use strict;
 use warnings;
 
-our $VERSION = '1.6.0'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Helper::File::Spec;
 use Rex::Logger;
@@ -61,7 +61,7 @@ our (
   $set_no_append,            $use_net_openssh_if_present,
   $use_template_ng,          $use_rex_kvm_agent,
   $autodie,                  $task_chaining_cmdline_args,
-
+  $waitpid_blocking_sleep_time,
 );
 
 # some defaults
@@ -454,7 +454,7 @@ sub get_user {
     return getlogin;
   }
   else {
-    return getpwuid($<);
+    return scalar getpwuid($<);
   }
 }
 
@@ -679,8 +679,8 @@ sub get_ssh_config_hostname {
     && exists $SSH_CONFIG_FOR{ $param->{server} }
     && exists $SSH_CONFIG_FOR{ $param->{server} }->{hostname} )
   {
-    if ( $SSH_CONFIG_FOR{ $param->{server} }->{hostname} =~ m/^\%h\.(.*)/ ) {
-      return $param->{server} . "." . $1;
+    if ( $SSH_CONFIG_FOR{ $param->{server} }->{hostname} =~ m/^\%h(\.(.*))?/ ) {
+      return $param->{server} . $1;
     }
     else {
       return $SSH_CONFIG_FOR{ $param->{server} }->{hostname};
@@ -1006,7 +1006,7 @@ sub _parse_ssh_config {
 
     if ( $line =~ m/^Host(?:\s*=\s*|\s+)(.*)$/i ) {
       my $host_tmp = $1;
-      @host = split( /\s+/, $host_tmp );
+      @host    = split( /\s+/, $host_tmp );
       $in_host = 1;
       for my $h (@host) {
         $ret{$h} = {};
@@ -1068,12 +1068,20 @@ sub get_use_server_auth {
   return 0;
 }
 
+sub set_waitpid_blocking_sleep_time {
+  my ( $self, $waitpid_blocking_sleep_time ) = @_;
+}
+
+sub get_waitpid_blocking_sleep_time {
+  return $waitpid_blocking_sleep_time // 0.1;
+}
+
 sub import {
   read_ssh_config_file();
   read_config_file();
 }
 
-no strict 'refs';
+no strict 'refs'; ## no critic ProhibitNoStrict
 __PACKAGE__->register_config_handler(
   base => sub {
     my ($param) = @_;
@@ -1103,7 +1111,7 @@ __PACKAGE__->register_config_handler(
 my @set_handler =
   qw/user password private_key public_key -keyauth -passwordauth -passauth
   parallelism sudo_password connection ca cert key distributor
-  template_function port/;
+  template_function port waitpid_blocking_sleep_time/;
 for my $hndl (@set_handler) {
   __PACKAGE__->register_set_handler(
     $hndl => sub {
