@@ -9,7 +9,7 @@ package Rex::Helper::File::Stat;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 require Rex::Helper::File::Stat::Unix;
 require Rex::Helper::File::Stat::Win32;
@@ -49,6 +49,11 @@ sub S_ISSOCK {
   _fcntl()->S_ISSOCK(@_);
 }
 
+sub S_IMODE {
+  shift;
+  _fcntl()->S_IMODE(@_);
+}
+
 sub _fcntl {
   if ( $^O =~ m/^MSWin/ ) {
     return "Rex::Helper::File::Stat::Win32";
