@@ -9,13 +9,16 @@ package Rex::Interface::Exec::OpenSSH;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Helper::SSH2;
 require Rex::Commands;
 use Rex::Interface::Exec::SSH;
+use Rex::Interface::Exec::IOReader;
 
-use base qw(Rex::Interface::Exec::SSH);
+use IO::Select;
+
+use base qw(Rex::Interface::Exec::SSH Rex::Interface::Exec::IOReader);
 
 sub new {
   my $that  = shift;
@@ -35,26 +38,18 @@ sub _exec {
   my $tty = !Rex::Config->get_no_tty;
 
   ( undef, $out_fh, $err_fh, $pid ) = $ssh->open3( { tty => $tty }, $exec );
-  while ( my $line = <$out_fh> ) {
-    $line =~ s/(\r?\n)$/\n/;
-    $out .= $line;
-    $self->execute_line_based_operation( $line, $option )
-      && do { kill( 'KILL', $pid ); goto END_OPEN };
 
-  }
-  while ( my $line = <$err_fh> ) {
-    $line =~ s/(\r?\n)$/\n/;
-    $err .= $line;
-    $self->execute_line_based_operation( $line, $option )
-      && do { kill( 'KILL', $pid ); goto END_OPEN };
-  }
+  ( $out, $err ) = $self->io_read( $out_fh, $err_fh, $pid, $option );
 
-END_OPEN:
   waitpid( $pid, 0 ) or die($!);
   if ( $ssh->error || $? ) {
-    $? = $? >> 8;
-  }
 
+    # we need to bitshift $? so that $? contains the right (and for all
+    # connection methods the same) exit code after a run()/i_run() call.
+    # this is for the user, so that he can query $? in his task.
+    $? >>= 8;
+  }
   return ( $out, $err );
 }
+
 1;
