@@ -9,7 +9,7 @@ package Rex::Interface::Fs::SSH;
 use strict;
 use warnings;
 
-our $VERSION = '1.4.1'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Helper::File::Stat;
 use Rex::Helper::Encode;
@@ -66,9 +66,9 @@ sub is_dir {
 
   Rex::Commands::profiler()->end("is_dir: $path");
 
-  defined $stat
+  defined $stat && defined $stat->{mode}
     ? return Rex::Helper::File::Stat->S_ISDIR( $stat->{mode} )
-    : return undef;
+    : return undef; ## no critic ProhibitExplicitReturnUndef
 }
 
 sub is_file {
@@ -78,17 +78,16 @@ sub is_file {
 
   my $sftp = Rex::get_sftp();
   my $stat = $sftp->stat($file);
-
   Rex::Commands::profiler()->end("is_file: $file");
 
-  defined $stat
+  defined $stat && defined $stat->{mode}
     ? return ( Rex::Helper::File::Stat->S_ISREG( $stat->{mode} )
       || Rex::Helper::File::Stat->S_ISLNK( $stat->{mode} )
       || Rex::Helper::File::Stat->S_ISBLK( $stat->{mode} )
       || Rex::Helper::File::Stat->S_ISCHR( $stat->{mode} )
       || Rex::Helper::File::Stat->S_ISFIFO( $stat->{mode} )
       || Rex::Helper::File::Stat->S_ISSOCK( $stat->{mode} ) )
-    : return undef;
+    : return undef; ## no critic ProhibitExplicitReturnUndef
 }
 
 sub unlink {
@@ -136,7 +135,7 @@ sub stat {
   my $sftp = Rex::get_sftp();
   my %ret  = $sftp->stat($file);
 
-  if ( !%ret ) { return undef; }
+  if ( !%ret ) { return undef; } ## no critic ProhibitExplicitReturnUndef
 
   $ret{'mode'} =
     sprintf( "%04o", Rex::Helper::File::Stat->S_IMODE( $ret{'mode'} ) );
