@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use Rex::Interface::Shell::Csh;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use base qw(Rex::Interface::Shell::Csh);
 
@@ -24,15 +24,4 @@ sub new {
   return $self;
 }
 
-sub detect {
-  my ( $self, $con ) = @_;
-
-  my ($shell_path) = $con->_exec("echo \$SHELL");
-  if ( $shell_path =~ m/\/tcsh$/ ) {
-    return 1;
-  }
-
-  return 0;
-}
-
 1;
