@@ -11,7 +11,7 @@ use warnings;
 use Rex::Helper::Run;
 use Rex::Interface::Exec;
 
-our $VERSION = '1.6.0'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 sub new {
   my $that  = shift;
@@ -63,6 +63,7 @@ sub update {
   my ( $self, $pkg, $option ) = @_;
 
   my $version = $option->{'version'} || '';
+  my $env     = $option->{'env'}     || ();
 
   Rex::Logger::debug( "Installing $pkg" . ( $version ? "-$version" : "" ) );
   my $cmd = sprintf $self->{commands}->{install}, $pkg;
@@ -72,7 +73,7 @@ sub update {
       $option->{version};
   }
 
-  my $f = i_run $cmd, fail_ok => 1;
+  my $f = i_run $cmd, fail_ok => 1, env => $env;
 
   unless ( $? == 0 ) {
     Rex::Logger::info( "Error installing $pkg.", "warn" );
@@ -102,7 +103,7 @@ sub update_system {
 
   if ( $option{update_packages} ) {
     my $cmd = $self->{commands}->{update_system};
-    my $f = i_run $cmd, fail_ok => 1;
+    my $f   = i_run $cmd, fail_ok => 1;
 
     unless ( $? == 0 ) {
       Rex::Logger::debug($f);
@@ -116,7 +117,7 @@ sub update_system {
     }
     else {
       my $cmd = $self->{commands}->{dist_update_system};
-      my $f = i_run $cmd, fail_ok => 1;
+      my $f   = i_run $cmd, fail_ok => 1;
 
       unless ( $? == 0 ) {
         Rex::Logger::debug($f);
