@@ -7,11 +7,7 @@ package Rex::Service::Gentoo::systemd;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
-
-use Rex::Commands::Run;
-use Rex::Logger;
-use Rex::Commands::Fs;
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Service::Redhat::systemd;
 use base qw(Rex::Service::Redhat::systemd);
