@@ -9,10 +9,8 @@ package Rex::Service::NetBSD;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
-use Rex::Commands::Run;
-use Rex::Helper::Run;
 use Rex::Commands::File;
 use Rex::Logger;
 
@@ -44,11 +42,16 @@ sub ensure {
 
   if ( $what =~ /^stop/ ) {
     $self->stop( $service, $options );
-    delete_lines_matching "/etc/rc.conf", matching => qr/${service}=YES/;
+    file "/etc/rc.conf.d/${service}", ensure => "absent";
+    delete_lines_matching "/etc/rc.conf",
+      matching => qr/^\s*${service}="?((?i)YES)"?/;
   }
   elsif ( $what =~ /^start/ || $what =~ m/^run/ ) {
     $self->start( $service, $options );
-    append_if_no_such_line "/etc/rc.conf", "${service}=YES\n";
+    file "/etc/rc.conf.d/${service}", ensure => "absent";
+    append_or_amend_line "/etc/rc.conf",
+      line   => "${service}=YES",
+      regexp => qr/^\s*${service}="?((?i)YES|NO)"?/;
   }
 
   return 1;
