@@ -9,11 +9,7 @@ package Rex::Service::OpenWrt;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
-
-use Rex::Commands::Run;
-use Rex::Helper::Run;
-use Rex::Logger;
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Service::Debian;
 use base qw(Rex::Service::Debian);
