@@ -9,9 +9,8 @@ package Rex::Service::SunOS;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
-use Rex::Commands::Run;
 use Rex::Helper::Run;
 use Rex::Logger;
 use Rex::Commands::Fs;
@@ -44,7 +43,7 @@ sub ensure {
 
   if ( $what =~ /^stop/ ) {
     $self->stop( $service, $options );
-    i_run "rm /etc/rc*.d/S*$service";
+    eval { i_run "rm /etc/rc*.d/S*$service"; };
   }
   elsif ( $what =~ /^start/ || $what =~ m/^run/ ) {
     $self->start( $service, $options );
