@@ -9,9 +9,8 @@ package Rex::Service::SunOS::svcadm;
 use strict;
 use warnings;
 
-our $VERSION = '1.4.1'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
-use Rex::Commands::Run;
 use Rex::Helper::Run;
 use Rex::Logger;
 use Rex::Commands::Fs;
@@ -38,7 +37,7 @@ sub new {
 sub status {
   my ( $self, $service, $options ) = @_;
 
-  my ($state) = map { /state\s+([a-z]+)/ } i_run "svcs -l $service";
+  my ($state) = map { /state\s+([a-z]+)/ } eval { i_run "svcs -l $service"; };
 
   if ( $state eq "online" ) {
     return 1;
@@ -65,8 +64,15 @@ sub ensure {
 sub action {
   my ( $self, $service, $action ) = @_;
 
-  i_run "svcadm $action $service >/dev/null", nohup => 1;
-  if ( $? == 0 ) { return 1; }
+  my $ret_val;
+  eval {
+    i_run "svcadm $action $service >/dev/null", nohup => 1;
+    $ret_val = 1;
+  } or do {
+    $ret_val = 0;
+  };
+
+  return $ret_val;
 }
 
 1;
