@@ -14,12 +14,18 @@ The Task Object. Typically you only need this class if you want to manipulate ta
 
 =head1 SYNOPSIS
 
- use Rex::Task
+ use Rex::Task;
  
-  my $task = Rex::Task->new(name => "testtask");
-  $task->set_server("remoteserver");
-  $task->set_code(sub { say "Hello"; });
-  $task->modify("no_ssh", 1);
+ # create a new task
+ my $task = Rex::Task->new(name => "testtask");
+ $task->set_server("remoteserver");
+ $task->set_code(sub { say "Hello"; });
+ $task->modify("no_ssh", 1);
+ 
+ # retrieve an existing task
+ use Rex::TaskList;
+ 
+ my $existing_task = Rex::TaskList->get_task('my_task');
 
 =head1 METHODS
 
@@ -32,7 +38,7 @@ use warnings;
 use Data::Dumper;
 use Time::HiRes qw(time);
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::TaskList;
@@ -56,27 +62,28 @@ require Rex::Args;
 
 This is the constructor.
 
-  $task = Rex::Task->new(
-    func => sub { some_code_here },
-    server => [ @server ],
-    desc => $description,
-    no_ssh => $no_ssh,
-    hidden => $hidden,
-    auth => {
-      user      => $user,
-      password   => $password,
-      private_key => $private_key,
-      public_key  => $public_key,
-    },
-    before => [sub {}, sub {}, ...],
-    after  => [sub {}, sub {}, ...],
-    around => [sub {}, sub {}, ...],
-    before_task_start => [sub {}, sub {}, ...],
-    after_task_finished => [sub {}, sub {}, ...],
-    name => $task_name,
-    executor => Rex::Interface::Executor->create,
-  );
-
+ $task = Rex::Task->new(
+   func => sub { some_code_here },
+   server => [ @server ],
+   desc => $description,
+   no_ssh => $no_ssh,
+   hidden => $hidden,
+   auth => {
+     user      => $user,
+     password   => $password,
+     private_key => $private_key,
+     public_key  => $public_key,
+   },
+   before => [sub {}, sub {}, ...],
+   after  => [sub {}, sub {}, ...],
+   around => [sub {}, sub {}, ...],
+   before_task_start => [sub {}, sub {}, ...],
+   after_task_finished => [sub {}, sub {}, ...],
+   name => $task_name,
+   executor => Rex::Interface::Executor->create,
+   opts => {key1 => val1, key2 => val2, ...},
+   args => [arg1, arg2, ...],
+ );
 
 =cut
 
@@ -94,6 +101,8 @@ sub new {
   $self->{no_ssh}   ||= 0;
   $self->{func}     ||= sub { };
   $self->{executor} ||= Rex::Interface::Executor->create;
+  $self->{opts}     ||= {};
+  $self->{args}     ||= [];
 
   $self->{connection} = undef;
 
@@ -121,6 +130,11 @@ sub connection {
   $self->{connection};
 }
 
+sub set_connection {
+  my ( $self, $conn ) = @_;
+  $self->{connection} = $conn;
+}
+
 =head2 executor
 
 Returns the current executor object.
@@ -174,7 +188,8 @@ sub server {
     }
   }
 
-  if ( ref( $self->{server} ) eq "ARRAY" && scalar( @{ $self->{server} } ) > 0 )
+  if ( ref( $self->{server} ) eq "ARRAY"
+    && scalar( @{ $self->{server} } ) > 0 )
   {
     for my $srv ( @{ $self->{server} } ) {
       if ( ref($srv) eq "CODE" ) {
@@ -303,12 +318,24 @@ sub is_http {
       && lc( $self->{"connection_type"} ) eq "http" );
 }
 
+=head2 is_https
+
+Returns true (1) if the task gets executed over https protocol.
+
+=cut
+
 sub is_https {
   my ($self) = @_;
   return ( $self->{"connection_type"}
       && lc( $self->{"connection_type"} ) eq "https" );
 }
 
+=head2 is_openssh
+
+Returns true (1) if the task gets executed with openssh.
+
+=cut
+
 sub is_openssh {
   my ($self) = @_;
   return ( $self->{"connection_type"}
@@ -330,13 +357,25 @@ sub want_connect {
 
 This method tries to guess the right connection type for the task and returns it.
 
-Current return values are SSH, Fake and Local.
+Current return values are below:
 
-SSH - will create a ssh connection to the remote server
+=over 4
 
-Local - will not create any connections
+=item * SSH: connect to the remote server using Net::SSH2
 
-Fake - will not create any connections. But it populates the connection properties so you can use this type to iterate over a list of remote hosts but don't let rex build a connection. For example if you want to use Sys::Virt or other modules.
+=item * OpenSSH: connect to the remote server using Net::OpenSSH
+
+=item * Local: runs locally (without any connections)
+
+=item * HTTP: uses experimental HTTP connection
+
+=item * HTTPS: uses experimental HTTPS connection
+
+=item * Fake: populate the connection properties, but do not connect
+
+So you can use this type to iterate over a list of remote hosts, but don't let rex build a connection. For example if you want to use Sys::Virt or other modules.
+
+=back
 
 =cut
 
@@ -382,6 +421,12 @@ sub modify {
   $self->rethink_connection;
 }
 
+=head2 rethink_connection
+
+Deletes current connection object.
+
+=cut
+
 sub rethink_connection {
   my ($self) = @_;
   delete $self->{connection};
@@ -389,7 +434,7 @@ sub rethink_connection {
 
 =head2 user
 
-Returns the current user the task will use.
+Returns the username the task will use.
 
 =cut
 
@@ -402,7 +447,7 @@ sub user {
 
 =head2 set_user($user)
 
-Set the user of a task.
+Set the username of a task.
 
 =cut
 
@@ -476,18 +521,19 @@ This method is used internally to execute the specified hooks.
 
 sub run_hook {
   my ( $self, $server, $hook, @more_args ) = @_;
+  my $old_server;
 
   for my $code ( @{ $self->{$hook} } ) {
     if ( $hook eq "after" ) { # special case for after hooks
-      &$code(
+      $code->(
         $$server,
-        ( $self->{"__was_authenticated"} ? undef : 1 ),
-        { Rex::Args->get }, @more_args
+        ( $self->{"__was_authenticated"} || 0 ),
+        { $self->get_opts }, @more_args
       );
     }
     else {
-      my $old_server = $$server if $server;
-      &$code( $$server, $server, { Rex::Args->get }, @more_args );
+      $old_server = $$server if $server;
+      $code->( $$server, $server, { $self->get_opts }, @more_args );
       if ( $old_server && $old_server ne $$server ) {
         $self->{current_server} = $$server;
       }
@@ -533,6 +579,12 @@ sub merge_auth {
   return \%auth;
 }
 
+=head2 get_sudo_password
+
+Returns the sudo password.
+
+=cut
+
 sub get_sudo_password {
   my ($self) = @_;
 
@@ -578,6 +630,12 @@ sub connect {
   }
   $self->{current_server} = $server;
 
+  $self->run_hook( \$server, "before" );
+
+  # need to be called, in case of a run_task task call.
+  # see #788
+  $self->rethink_connection;
+
   my $user = $self->user;
 
   #print Dumper($self);
@@ -593,10 +651,8 @@ sub connect {
   Rex::Logger::debug("Auth-Information inside Task:");
   for my $key ( keys %{$auth} ) {
     my $data = $auth->{$key};
-    if ( $key eq "password" ) {
-      $data = Rex::Logger::masq( "%s", $data );
-    }
-
+    $data = Rex::Logger::masq( "%s", $data ) if $key eq 'password';
+    $data = Rex::Logger::masq( "%s", $data ) if $key eq 'sudo_password';
     $data ||= "";
 
     Rex::Logger::debug("$key => [[$data]]");
@@ -620,13 +676,15 @@ sub connect {
       ssh      => $self->connection->get_connection_object,
       server   => $server,
       cache    => Rex::Interface::Cache->create(),
-      task     => $self,
+      task     => [],
       profiler => $profiler,
       reporter => Rex::Report->create( Rex::Config->get_report_type ),
       notify   => Rex::Notify->new(),
     }
   );
 
+  push @{ Rex::get_current_connection()->{task} }, $self;
+
   $profiler->start("connect");
   eval {
     $self->connection->connect(%connect_hash);
@@ -644,8 +702,11 @@ sub connect {
   }
   elsif ( !$self->connection->is_authenticated ) {
     Rex::pop_connection();
-    my $message = "Wrong username/password or wrong key on $server.";
-    $message .= " Or root is not permitted to login over SSH."
+    my $message =
+      "Couldn't authenticate against $server. It may be caused by one or more of:\n";
+    $message .= " - wrong username, password, key or passphrase\n";
+    $message .= " - changed remote host key\n";
+    $message .= " - root is not permitted to login over SSH\n"
       if ( $connect_hash{user} eq 'root' );
 
     if ( !exists $override{auth} ) {
@@ -663,7 +724,7 @@ sub connect {
     croak($message);
   }
   else {
-    Rex::Logger::info("Successfully authenticated on $server.")
+    Rex::Logger::debug("Successfully authenticated on $server.")
       if ( $self->connection->get_connection_type ne "Local" );
     $self->{"__was_authenticated"} = 1;
   }
@@ -693,10 +754,20 @@ sub disconnect {
 
   delete $self->{connection};
 
+  pop @{ Rex::get_current_connection()->{task} };
+
   # need to get rid of this
   Rex::pop_connection();
+
+  $self->run_hook( \$server, "after" );
 }
 
+=head2 get_data
+
+Dump task data.
+
+=cut
+
 sub get_data {
   my ($self) = @_;
 
@@ -713,47 +784,61 @@ sub get_data {
     name            => $self->{name},
     executor        => $self->{executor},
     connection_type => $self->{connection_type},
+    opts            => $self->{opts},
+    args            => $self->{args},
   };
 }
 
-#####################################
-# deprecated functions
-# for compatibility
-#####################################
-
 =head2 run($server, %options)
 
-Run the task on $server.
+Run the task on C<$server>, with C<%options>.
 
 =cut
 
 sub run {
+  return pre_40_run(@_) unless ref $_[0];
 
-  # someone used this function directly... bail out
-  if ( ref( $_[0] ) ) {
-    my ( $self, $server, %options ) = @_;
+  my ( $self, $server, %options ) = @_;
 
-    if ( !ref $server ) {
-      $server = Rex::Group::Entry::Server->new( name => $server );
+  $options{opts}   ||= { $self->get_opts };
+  $options{args}   ||= [ $self->get_args ];
+  $options{params} ||= $options{opts};
+
+  if ( !ref $server ) {
+    $server = Rex::Group::Entry::Server->new( name => $server );
+  }
+
+  if ( !$_[1] ) {
+
+    # run is called without any server.
+    # so just connect to any servers.
+    return Rex::TaskList->create()->run( $self, %options );
+  }
+
+  # this is a method call
+  # so run the task
+
+  # TODO: refactor complete task calling
+  #       direct call with function and normal task call
+
+  my ( $in_transaction, $start_time );
+
+  $start_time = time;
+
+  if ( $server ne "<func>" ) {
+
+    # this is _not_ a task call via function syntax.
+
+    $in_transaction = $options{in_transaction};
+
+    eval { $self->connect($server) };
+    if ($@) {
+      my $error = $@;
+      $self->{"__was_authenticated"} = 0;
+      $self->run_hook( \$server, "after" );
+      die $error;
     }
 
-    if ( !$_[1] ) {
-
-      # run is called without any server.
-      # so just connect to any servers.
-      return Rex::TaskList->create()->run( $self->name, %options );
-    }
-
-    # this is a method call
-    # so run the task
-
-    my $in_transaction = $options{in_transaction};
-
-    $self->run_hook( \$server, "before" );
-    $self->connect($server);
-
-    my $start_time = time;
-
     if ( Rex::Args->is_opt("c") ) {
 
       # get and cache all os info
@@ -765,39 +850,61 @@ sub run {
 
     if ( !$server->test_perl ) {
       Rex::Logger::info(
-        "There is no perl interpreter found on this system. Some commands may not work. Sudo won't work.",
+        "There is no perl interpreter found on this system. "
+          . "Some commands may not work. Sudo won't work.",
         "warn"
       );
       sleep 3;
     }
 
-    # execute code
-    my $ret;
+  }
+  else {
+# we need to push the connection information of the last task onto this task object
+# if we don't do this, the task doesn't have any information of the current connection when called like a function.
+# See: #1091
+    $self->set_connection(
+      Rex::get_current_connection()->{task}->[-1]->connection )
+      if Rex::get_current_connection()->{task}->[-1];
+    push @{ Rex::get_current_connection()->{task} }, $self;
+  }
 
-    eval {
-      $ret = $self->executor->exec( $options{params} );
-      my $notify = Rex::get_current_connection()->{notify};
-      $notify->run_postponed();
-    } or do {
-      if ($@) {
-        my $error = $@;
+  # execute code
+  my @ret;
+  my $wantarray = wantarray;
 
-        Rex::get_current_connection()->{reporter}
-          ->report_resource_failed( message => $error );
+  eval {
+    $self->set_opts( %{ $options{params} } )
+      if ref $options{params} eq "HASH";
+    if ($wantarray) {
+      @ret = $self->executor->exec( $options{params}, $options{args} );
+    }
+    else {
+      $ret[0] = $self->executor->exec( $options{params}, $options{args} );
+    }
+    my $notify = Rex::get_current_connection()->{notify};
+    $notify->run_postponed();
+  } or do {
+    if ($@) {
+      my $error = $@;
 
-        Rex::get_current_connection()->{reporter}->report_task_execution(
-          failed     => 1,
-          start_time => $start_time,
-          end_time   => time,
-          message    => $error,
-        );
+      Rex::get_current_connection()->{reporter}
+        ->report_resource_failed( message => $error );
 
-        Rex::get_current_connection()->{reporter}->write_report();
+      Rex::get_current_connection()->{reporter}->report_task_execution(
+        failed     => 1,
+        start_time => $start_time,
+        end_time   => time,
+        message    => $error,
+      );
 
-        die($error);
-      }
-    };
+      Rex::get_current_connection()->{reporter}->write_report();
 
+      pop @{ Rex::get_current_connection()->{task} };
+      die($error);
+    }
+  };
+
+  if ( $server ne "<func>" ) {
     if ( Rex::Args->is_opt("c") ) {
 
       # get and cache all os info
@@ -812,25 +919,45 @@ sub run {
 
     Rex::get_current_connection()->{reporter}->write_report();
 
-    $self->disconnect($server) unless ($in_transaction);
-    $self->run_hook( \$server, "after" );
-
-    return $ret;
+    if ($in_transaction) {
+      $self->run_hook( \$server, "around", 1 );
+      $self->run_hook( \$server, "after" );
+    }
+    else {
+      $self->disconnect($server);
+    }
+  }
+  else {
+    pop @{ Rex::get_current_connection()->{task} };
   }
 
+  if ($wantarray) {
+    return @ret;
+  }
   else {
-    my ( $class, $task, $server_overwrite, $params ) = @_;
-    Rex::deprecated( "Rex::Task->run()", "0.40" );
-
-    if ($server_overwrite) {
-      Rex::TaskList->create()->get_task($task)->set_server($server_overwrite);
-    }
-
-    # this is a deprecated static call
-    Rex::TaskList->create()->run( $task, params => $params );
+    return $ret[0];
   }
 }
 
+sub pre_40_run {
+  my ( $class, $task_name, $server_overwrite, $params ) = @_;
+
+  # static calls to this method are deprecated
+  Rex::deprecated( "Rex::Task->run()", "0.40" );
+
+  my $tasklist = Rex::TaskList->create;
+  my $task     = $tasklist->get_task($task_name);
+
+  $task->set_server($server_overwrite) if $server_overwrite;
+  $tasklist->run( $task, params => $params );
+}
+
+=head2 modify_task($task, $key => $value)
+
+Modify C<$task>, by setting C<$key> to C<$value>.
+
+=cut
+
 sub modify_task {
   my $class = shift;
   my $task  = shift;
@@ -840,22 +967,40 @@ sub modify_task {
   Rex::TaskList->create()->get_task($task)->modify( $key => $value );
 }
 
+=head2 is_task
+
+Returns true(1) if the passed object is a task.
+
+=cut
+
 sub is_task {
   my ( $class, $task ) = @_;
   return Rex::TaskList->create()->is_task($task);
 }
 
+=head2 get_tasks
+
+Returns list of tasks.
+
+=cut
+
 sub get_tasks {
   my ( $class, @tmp ) = @_;
   return Rex::TaskList->create()->get_tasks(@tmp);
 }
 
+=head2 get_desc
+
+Returns description of task.
+
+=cut
+
 sub get_desc {
   my ( $class, @tmp ) = @_;
   return Rex::TaskList->create()->get_desc(@tmp);
 }
 
-=head2 exit_on_connect_fail()
+=head2 exit_on_connect_fail
 
 Returns true if rex should exit on connect failure.
 
@@ -866,9 +1011,81 @@ sub exit_on_connect_fail {
   return $self->{exit_on_connect_fail};
 }
 
+=head2 set_exit_on_connect_fail
+
+Sets if rex should exit on connect failure.
+
+=cut
+
 sub set_exit_on_connect_fail {
   my ( $self, $exit ) = @_;
   $self->{exit_on_connect_fail} = $exit;
 }
 
+=head2 get_args
+
+Returns arguments of task.
+
+=cut
+
+sub get_args {
+  my ($self) = @_;
+  @{ $self->{args} || [] };
+}
+
+=head2 get_opts
+
+Returns options of task.
+
+=cut
+
+sub get_opts {
+  my ($self) = @_;
+  %{ $self->{opts} || {} };
+}
+
+=head2 set_args
+
+Sets arguments for task.
+
+=cut
+
+sub set_args {
+  my ( $self, @args ) = @_;
+  $self->{args} = \@args;
+}
+
+=head2 set_opt
+
+Sets an option for task.
+
+=cut
+
+sub set_opt {
+  my ( $self, $key, $value ) = @_;
+  $self->{opts}->{$key} = $value;
+}
+
+=head2 set_opts
+
+Sets options for task.
+
+=cut
+
+sub set_opts {
+  my ( $self, %opts ) = @_;
+  $self->{opts} = \%opts;
+}
+
+=head2 clone
+
+Clones a task.
+
+=cut
+
+sub clone {
+  my $self = shift;
+  return Rex::Task->new( %{ $self->get_data } );
+}
+
 1;
