@@ -11,8 +11,26 @@ use warnings;
 use Rex -base;
 use Data::Dumper;
 use Rex::Commands::Box;
+require Rex::CLI;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
+
+BEGIN {
+  use Rex::Shared::Var;
+  share qw(@exit);
+}
+
+Rex::CLI->add_exit(
+  sub {
+    if ( scalar @exit > 0 ) {
+      CORE::exit(1);
+    }
+  }
+);
+
+sub push_exit {
+  push @exit, shift;
+}
 
 desc 'Run tests specified with --test=testfile (default: t/*.t)';
 task run => make {
@@ -28,7 +46,7 @@ task run => make {
 
   for my $file (@files) {
     Rex::Logger::info("Running test: $file.");
-    do "$file";
+    do "./$file";
     Rex::Logger::info( "Error running $file: $@", "error" ) if $@;
   }
 };
