@@ -9,7 +9,7 @@ package Rex::Virtualization::Docker::daemon;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -22,7 +22,7 @@ sub execute {
 
   Rex::Logger::debug("starting docker daemon");
 
-  i_run "docker -d -H $host -ip $bind";
+  i_run "docker -d -H $host -ip $bind", fail_ok => 1;
   if ( $? != 0 ) {
     die("Error starting docker daemon");
   }
