@@ -9,7 +9,7 @@ package Rex::Virtualization::Docker::delete;
 use strict;
 use warnings;
 
-our $VERSION = '1.4.1'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -28,7 +28,7 @@ sub execute {
     die("VM $dom not found.");
   }
 
-  i_run "docker rm \"$dom\"";
+  i_run "docker rm \"$dom\"", fail_ok => 1;
   if ( $? != 0 ) {
     die("Error deleteing container $dom");
   }
