@@ -9,7 +9,7 @@ package Rex::Virtualization::LibVirt::clone;
 use strict;
 use warnings;
 
-our $VERSION = '1.6.0'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -29,8 +29,10 @@ sub execute {
     die("You have to define the new vm name!");
   }
 
+  my $connect = Rex::Config->get('virtualization')->{connect};
+
   i_run
-    "/usr/bin/virt-clone --connect qemu:///system -o '$vmname' -n '$newname' --auto-clone";
+    "/usr/bin/virt-clone --connect '$connect' -o '$vmname' -n '$newname' --auto-clone";
 }
 
 1;
