@@ -9,7 +9,7 @@ package Rex::Virtualization::LibVirt::shutdown;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -31,7 +31,7 @@ sub execute {
     die("VM $dom not found.");
   }
 
-  i_run "virsh -c $uri shutdown '$dom'";
+  i_run "virsh -c $uri shutdown '$dom'", fail_ok => 1;
   if ( $? != 0 ) {
     die("Error shutdown vm $dom");
   }
