@@ -9,7 +9,7 @@ package Rex::Virtualization::LibVirt::start;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -34,7 +34,7 @@ sub execute {
     die("VM $dom not found.");
   }
 
-  my $output = i_run "virsh -c $uri start '$dom' 2>&1";
+  my $output = i_run "virsh -c $uri start '$dom' 2>&1", fail_ok => 1;
   if ( $? != 0 ) {
     die("Error starting vm $dom\nError: $output");
   }
