@@ -9,7 +9,7 @@ package Rex::Virtualization::VBox::bridge;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -19,7 +19,7 @@ use Data::Dumper;
 sub execute {
   my $class = shift;
 
-  my $result = i_run "VBoxManage list bridgedifs";
+  my $result = i_run "VBoxManage list bridgedifs", fail_ok => 1;
   if ( $? != 0 ) {
     die("Error running VBoxManage list bridgedifs");
   }
@@ -28,7 +28,7 @@ sub execute {
   my @blocks = split /\n\n/m, $result;
   for my $block (@blocks) {
 
-    my $if = {};
+    my $if    = {};
     my @lines = split /\n/, $block;
     for my $line (@lines) {
       if ( $line =~ /^Name:\s+(.+?)$/ ) {
