@@ -9,7 +9,7 @@ package Rex::Virtualization::VBox::guestinfo;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -70,7 +70,8 @@ sub _get_property {
   my ($got_value) = (0);
 
   while ( $got_value != 1 ) {
-    my @a_tmp = i_run "VBoxManage guestproperty get \"$vmname\" \"$prop\"";
+    my @a_tmp = i_run "VBoxManage guestproperty get \"$vmname\" \"$prop\"",
+      fail_ok => 1;
 
     if ( $a_tmp[0] =~ m/No value set/ ) {
       sleep 1;
