@@ -9,7 +9,7 @@ package Rex::Virtualization::VBox::info;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -29,7 +29,8 @@ sub execute {
 
   my $xml;
 
-  my @dominfo = i_run "VBoxManage showvminfo \"$vmname\" --machinereadable";
+  my @dominfo = i_run "VBoxManage showvminfo \"$vmname\" --machinereadable",
+    fail_ok => 1;
 
   if ( $? != 0 ) {
     die("Error running VBoxManage showvminfo $vmname");
