@@ -9,7 +9,7 @@ package Rex::Virtualization::VBox::list;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -21,13 +21,13 @@ sub execute {
   my @domains;
 
   if ( $arg1 eq "all" ) {
-    @domains = i_run "VBoxManage list vms";
+    @domains = i_run "VBoxManage list vms", fail_ok => 1;
     if ( $? != 0 ) {
       die("Error running VBoxManage list vms");
     }
   }
   elsif ( $arg1 eq "running" ) {
-    @domains = i_run "VBoxManage list runningvms";
+    @domains = i_run "VBoxManage list runningvms", fail_ok => 1;
     if ( $? != 0 ) {
       die("Error running VBoxManage runningvms");
     }
@@ -41,7 +41,7 @@ sub execute {
     my ( $name, $id ) = $line =~ m:^"([^"]+)"\s*\{([^\}]+)\}$:;
 
     my @status = map { /^VMState="([^"]+)"$/ }
-      i_run "VBoxManage showvminfo \"{$id}\" --machinereadable";
+      i_run "VBoxManage showvminfo \"{$id}\" --machinereadable", fail_ok => 1;
     my $status;
 
     push(
