@@ -9,7 +9,7 @@ package Rex::Virtualization::VBox::option;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -41,7 +41,7 @@ sub execute {
       $func = $FUNC_MAP->{$opt};
     }
 
-    i_run "VBoxManage modifyvm \"$dom\" --$func \"$val\"";
+    i_run "VBoxManage modifyvm \"$dom\" --$func \"$val\"", fail_ok => 1;
     if ( $? != 0 ) {
       Rex::Logger::info( "Error setting $opt to $val on $dom ($@)", "warn" );
     }
