@@ -9,7 +9,7 @@ package Rex::Virtualization::VBox::shutdown;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.8.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -28,7 +28,7 @@ sub execute {
     die("VM $dom not found.");
   }
 
-  i_run "VBoxManage controlvm \"$dom\" acpipowerbutton";
+  i_run "VBoxManage controlvm \"$dom\" acpipowerbutton", fail_ok => 1;
   if ( $? != 0 ) {
     die("Error shutdown vm $dom");
   }
